Crate xwasm_utils

Crate xwasm_utils 

Modules

rules
stack_height
The pass that tries to make stack overflows deterministic, by introducing an upper bound of the stack size.

Structs

DeleteTransaction
Delete transaction.
Entry
Reference counting, link-handling object.
EntryRef
Reference to the entry in the rerence list.
Module
Module
RefList
List that tracks references and indices.
TargetSymbols

Enums

BuildError
OptimizerError
PackingError
Pack error.
SourceTarget
TargetRuntime

Functions

build
externalize
externalize_mem
graph_generate
Generate xwasm Module
graph_parse
New module from xwasm Module
inject_gas_counter
Injects gas counter.
inject_runtime_type
optimize
pack_instance
If a pxwasm module has an exported function matching “create” symbol we want to pack it into “constructor”. raw_module is the actual contract code ctor_module is the constructor which should return raw_module
shrink_unknown_stack
underscore_funcs
ununderscore_funcs